=== modified file 'examples/client.cc'
--- examples/client.cc	2011-11-24 00:05:44 +0000
+++ examples/client.cc	2011-11-24 03:44:17 +0000
@@ -132,7 +132,7 @@
         client.level= BUFFER_ALL;
       else
       {
-        printf("Invalid buffer level: %s\n", optarg);
+        fprintf(stderr, "Invalid buffer level: %s\n", optarg);
         exit(0);
       }
       break;
@@ -198,7 +198,7 @@
                                                     sizeof(client_con_st));
     if (client.client_con_list == NULL)
     {
-      printf("calloc:%d\n", errno);
+      fprintf(stderr, "calloc:%d\n", errno);
       exit(1);
     }
   }
@@ -206,13 +206,13 @@
   /* This may fail if there is other initialization that fails. See docs. */
   if ((client.drizzle= drizzle_create()) == NULL)
   {
-    printf("drizzle_create failed\n");
+    fprintf(stderr, "drizzle_create failed\n");
     exit(1);
   }
 
   if (blocking == 0)
   {
-    drizzle_add_options(client.drizzle, DRIZZLE_NON_BLOCKING);
+    drizzle_set_option(client.drizzle, DRIZZLE_NON_BLOCKING, true);
   }
 
   /* Start all connections, and if in non-blocking mode, return as soon as the
@@ -333,9 +333,13 @@
         column= drizzle_column_read(&(client_con->result),
                                     &(client_con->column), &ret);
         if (ret == DRIZZLE_RETURN_IO_WAIT)
+        {
           return 1;
+        }
         else if (ret != DRIZZLE_RETURN_OK)
+        {
           CLIENT_ERROR("drizzle_column_read", ret, client);
+        }
 
         if (column == NULL)
           break;
@@ -355,17 +359,17 @@
       {
         field_sizes= drizzle_row_field_sizes(&(client_con->result));
 
-        printf("Row: %" PRId64 "\n",
-               drizzle_row_current(&(client_con->result)));
+        printf("Row: %" PRId64 "\n", drizzle_row_current(&(client_con->result)));
 
         for (x= 0; x < drizzle_result_column_count(&(client_con->result)); x++)
         {
           if (row[x] == NULL)
+          {
             printf("     (NULL)\n");
+          }
           else
           {
-            printf("     (%"PRIu64") %.*s\n", static_cast<uint64_t>(field_sizes[x]), (int32_t)field_sizes[x],
-                   row[x]);
+            printf("     (%"PRIu64") %.*s\n", static_cast<uint64_t>(field_sizes[x]), (int32_t)field_sizes[x], row[x]);
           }
         }
 
@@ -424,15 +428,22 @@
             CLIENT_ERROR("drizzle_field_read", ret, client);
 
           if (field == NULL)
+          {
             printf("     (NULL)");
+          }
           else if (offset > 0)
+          {
             printf("%.*s", (int32_t)length, field);
+          }
           else
-            printf("     (%" PRIu64 " %.*s", (uint64_t)total,
-			    (int32_t)length, field);
+          {
+            printf("     (%" PRIu64 " %.*s", (uint64_t)total, (int32_t)length, field);
+          }
 
           if (offset + length == total)
+          {
             printf("\n");
+          }
 
           /* If we buffered the entire field, be sure to free it. */
           if (client->level == BUFFER_FIELD)

=== modified file 'examples/proxy.cc'
--- examples/proxy.cc	2011-11-24 00:05:44 +0000
+++ examples/proxy.cc	2011-11-24 03:44:17 +0000
@@ -155,7 +155,7 @@
     return 1;
   }
 
-  drizzle_add_options(drizzle, DRIZZLE_FREE_OBJECTS);
+  drizzle_set_option(drizzle, DRIZZLE_FREE_OBJECTS, true);
   drizzle_set_verbose(drizzle, verbose);
 
   if (drizzle_con_create(drizzle, con_listen) == NULL)

=== modified file 'examples/server.cc'
--- examples/server.cc	2011-11-04 21:06:16 +0000
+++ examples/server.cc	2011-11-24 03:44:17 +0000
@@ -41,7 +41,7 @@
 #include <stdlib.h>
 #include <unistd.h>
 
-#include <libdrizzle-1.0/drizzle_server.h>
+#include <libdrizzle-2.0/drizzle_server.h>
 
 #define DRIZZLE_FIELD_MAX 32
 #define DRIZZLE_RESULT_ROWS 20
@@ -70,7 +70,7 @@
   in_port_t port= 0;
   drizzle_verbose_t verbose= DRIZZLE_VERBOSE_NEVER;
   drizzle_return_t ret;
-  drizzle_st drizzle;
+  drizzle_st *drizzle;
   drizzle_con_st *con_listen= (drizzle_con_st*)malloc(sizeof(drizzle_con_st));
   drizzle_con_st *con= (drizzle_con_st*)malloc(sizeof(drizzle_con_st));
   drizzle_result_st result;
@@ -132,18 +132,18 @@
     }
   }
 
-  if (drizzle_create(&drizzle) == NULL)
+  if ((drizzle= drizzle_create()) == NULL)
   {
-    printf("drizzle_create:NULL\n");
+    fprintf(stderr, "drizzle_create:NULL\n");
     return 1;
   }
 
-  drizzle_add_options(&drizzle, DRIZZLE_FREE_OBJECTS);
-  drizzle_set_verbose(&drizzle, verbose);
+  drizzle_set_option(drizzle, DRIZZLE_FREE_OBJECTS, true);
+  drizzle_set_verbose(drizzle, verbose);
 
-  if (drizzle_con_create(&drizzle, con_listen) == NULL)
+  if (drizzle_con_create(drizzle, con_listen) == NULL)
   {
-    printf("drizzle_con_create:NULL\n");
+    fprintf(stderr, "drizzle_con_create:NULL\n");
     return 1;
   }
 
@@ -151,24 +151,26 @@
   drizzle_con_set_tcp(con_listen, host, port);
 
   if (mysql)
+  {
     drizzle_con_add_options(con_listen, DRIZZLE_CON_MYSQL);
+  }
 
   if (drizzle_con_listen(con_listen) != DRIZZLE_RETURN_OK)
   {
-    printf("drizzle_con_listen:%s\n", drizzle_error(&drizzle));
+    fprintf(stderr, "drizzle_con_listen:%s\n", drizzle_error(drizzle));
     return 1;
   }
 
   while (1)
   {
-    (void)drizzle_con_accept(&drizzle, con, &ret);
+    (void)drizzle_con_accept(drizzle, con, &ret);
     if (ret != DRIZZLE_RETURN_OK)
     {
-      printf("drizzle_con_accept:%s\n", drizzle_error(&drizzle));
+      fprintf(stderr, "drizzle_con_accept:%s\n", drizzle_error(drizzle));
       return 1;
     }
 
-    server(&drizzle, con, &result, &column);
+    server(drizzle, con, &result, &column);
 
     drizzle_con_free(con);
 
@@ -182,7 +184,7 @@
   }
 
   drizzle_con_free(con_listen);
-  drizzle_free(&drizzle);
+  drizzle_free(drizzle);
 
   free(con);
   free(con_listen);

=== modified file 'examples/sqlite_server.cc'
--- examples/sqlite_server.cc	2011-11-24 00:05:44 +0000
+++ examples/sqlite_server.cc	2011-11-24 03:44:17 +0000
@@ -169,7 +169,7 @@
     return 1;
   }
 
-  drizzle_add_options(server->drizzle, DRIZZLE_FREE_OBJECTS);
+  drizzle_set_option(server->drizzle, DRIZZLE_FREE_OBJECTS, true);
   drizzle_set_verbose(server->drizzle, server->verbose);
 
   if (drizzle_con_create(server->drizzle, con_listen) == NULL)

=== modified file 'libdrizzle-2.0/deprecated_enum.h'
--- libdrizzle-2.0/deprecated_enum.h	2011-11-21 00:54:34 +0000
+++ libdrizzle-2.0/deprecated_enum.h	2011-11-24 03:44:17 +0000
@@ -56,11 +56,9 @@
  */
 enum drizzle_options_t
 {
-  DRIZZLE_NONE=            0,
-  DRIZZLE_ALLOCATED=       (1 << 0),
-  DRIZZLE_NON_BLOCKING=    (1 << 1),
-  DRIZZLE_FREE_OBJECTS=    (1 << 2),
-  DRIZZLE_ASSERT_DANGLING= (1 << 3)
+  DRIZZLE_NON_BLOCKING,
+  DRIZZLE_FREE_OBJECTS,
+  DRIZZLE_ASSERT_DANGLING
 };
 
 #ifndef __cplusplus

=== modified file 'libdrizzle-2.0/drizzle.cc'
--- libdrizzle-2.0/drizzle.cc	2011-11-24 00:05:44 +0000
+++ libdrizzle-2.0/drizzle.cc	2011-11-24 03:44:17 +0000
@@ -196,6 +196,27 @@
   return drizzle->last_error;
 }
 
+drizzle_return_t drizzle_set_option(drizzle_st *drizzle, drizzle_options_t arg, bool set)
+{
+  switch (arg)
+  {
+  case DRIZZLE_NON_BLOCKING:
+    drizzle->options.is_non_blocking= set;
+    return DRIZZLE_RETURN_OK;
+
+  case DRIZZLE_FREE_OBJECTS:
+    return DRIZZLE_RETURN_OK;
+
+  case DRIZZLE_ASSERT_DANGLING:
+    return DRIZZLE_RETURN_OK;
+
+  default:
+    break;
+  }
+
+  return DRIZZLE_RETURN_INVALID_ARGUMENT;
+}
+
 int drizzle_errno(const drizzle_st *drizzle)
 {
   return drizzle->last_errno;
@@ -211,19 +232,6 @@
   return drizzle->sqlstate;
 }
 
-int drizzle_options(const drizzle_st *)
-{
-  return 0;
-}
-
-void drizzle_set_options(drizzle_st *, int)
-{
-}
-
-void drizzle_add_options(drizzle_st *, int)
-{
-}
-
 void *drizzle_context(const drizzle_st *drizzle)
 {
   return drizzle->context;

=== modified file 'libdrizzle-2.0/drizzle.h'
--- libdrizzle-2.0/drizzle.h	2011-11-24 00:05:44 +0000
+++ libdrizzle-2.0/drizzle.h	2011-11-24 03:44:17 +0000
@@ -214,46 +214,6 @@
 const char *drizzle_sqlstate(const drizzle_st *drizzle);
 
 /**
- * Get options for a drizzle structure.
- *
- * @param[in] drizzle Drizzle structure previously initialized with
- *  drizzle_create() or drizzle_clone().
- * @return Options set for the drizzle structure.
- */
-DRIZZLE_API
-int drizzle_options(const drizzle_st *drizzle);
-
-/**
- * Set options for a drizzle structure.
- *
- * @param[in] drizzle Drizzle structure previously initialized with
- *  drizzle_create() or drizzle_clone().
- * @param[in] options Available options for drizzle structure to set.
- */
-DRIZZLE_API
-void drizzle_set_options(drizzle_st *drizzle, int options);
-
-/**
- * Add options for a drizzle structure.
- *
- * @param[in] drizzle Drizzle structure previously initialized with
- *  drizzle_create() or drizzle_clone().
- * @param[in] options Available options for drizzle structure to add.
- */
-DRIZZLE_API
-void drizzle_add_options(drizzle_st *drizzle, int options);
-
-/**
- * Remove options for a drizzle structure.
- *
- * @param[in] drizzle Drizzle structure previously initialized with
- *  drizzle_create() or drizzle_clone().
- * @param[in] options Available options for drizzle structure to remove.
- */
-DRIZZLE_API
-void drizzle_remove_options(drizzle_st *, drizzle_options_t);
-
-/**
  * Get application context pointer.
  *
  * @param[in] drizzle Drizzle structure previously initialized with
@@ -390,6 +350,9 @@
 drizzle_con_st *drizzle_con_clone(drizzle_st *drizzle, drizzle_con_st *con,
                                   const drizzle_con_st *from);
 
+DRIZZLE_API
+drizzle_return_t drizzle_set_option(drizzle_st *drizzle, drizzle_options_t arg, bool set);
+
 /**
  * Free a connection structure.
  *

